==> mysql-5.7_5.7.33.orig.tar.gz: mysql-5.7.33/client/dump/i_output_writer.h <==
/*
  Copyright (c) 2015, Oracle and/or its affiliates. All rights reserved.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.

  This program is also distributed with certain software (including
  but not limited to OpenSSL) that is licensed under separate terms,
  as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
  separately licensed software that they have included with MySQL.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License, version 2.0, for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#ifndef I_OUTPUT_WRITER_INCLUDED
#define I_OUTPUT_WRITER_INCLUDED

#include "i_chain_element.h"
#include <string>

namespace Mysql{
namespace Tools{
namespace Dump{

class I_output_writer : public virtual I_chain_element
{
public:
  /**
    Adds new block of data atomically to output. Atomicity assures that
    specified block of data will be added to output as one part, will not be
    divided or interleaved with another data.
   */
  virtual void append(const std::string& data_to_append)= 0;
};

}
}
}

#endif

==> mysql-8.0_8.0.36.orig.tar.gz: mysql-8.0.36/client/dump/i_output_writer.h <==
/*
  Copyright (c) 2015, 2023, Oracle and/or its affiliates.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.

  This program is also distributed with certain software (including
  but not limited to OpenSSL) that is licensed under separate terms,
  as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
  separately licensed software that they have included with MySQL.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License, version 2.0, for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#ifndef I_OUTPUT_WRITER_INCLUDED
#define I_OUTPUT_WRITER_INCLUDED

#include <string>

#include "client/dump/i_chain_element.h"

namespace Mysql {
namespace Tools {
namespace Dump {

class I_output_writer : public virtual I_chain_element {
 public:
  /**
    Adds new block of data atomically to output. Atomicity assures that
    specified block of data will be added to output as one part, will not be
    divided or interleaved with another data.
   */
  virtual void append(const std::string &data_to_append) = 0;
  /**
    Initialize writer
  */
  virtual bool init() = 0;
};

}  // namespace Dump
}  // namespace Tools
}  // namespace Mysql

#endif
